@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: comp_tcp.pm 2675 2009-09-06 03:32:57Z rcaputo $
+# vim: ts=2 sw=2 expandtab
 
 # Exercise Server::TCP and later, when it's available, Client::TCP.
 
@@ -16,8 +16,14 @@ BEGIN {
 use Test::More tests => 34;
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-sub POE::Kernel::TRACE_DEFAULT  () { 1 }
-sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
+
+BEGIN {
+  package POE::Kernel;
+BEGIN {
+  $POE::Kernel::VERSION = '1.311';
+}
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
+}
 
 use POE qw( Component::Server::TCP Wheel::ReadWrite Component::Client::TCP );
 
