@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: k_alarms.pm 2371 2008-06-28 20:46:33Z rcaputo $
+# vim: ts=2 sw=2 expandtab
 
 # Tests alarms.
 
@@ -10,8 +10,14 @@ use lib qw(./mylib ../mylib);
 use Test::More tests => 37;
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-sub POE::Kernel::TRACE_DEFAULT  () { 1 }
-sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
+
+BEGIN {
+  package POE::Kernel;
+BEGIN {
+  $POE::Kernel::VERSION = '1.311';
+}
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
+}
 
 BEGIN { use_ok("POE") }
 
@@ -339,9 +345,9 @@ POE::Session->create(
 
       my $test_14     = $kernel->alarm_set( test_14 => 1 => 14 );
       my @test_array  = $kernel->alarm_remove( $test_14 );
-      ok($test_array[0] eq 'test_14', "alarm 14 remove: name is correct");
-      ok($test_array[1] == 1,         "alarm 14 remove: time is correct");
-      ok($test_array[2] == 14,        "alarm 14 remove: data is correct");
+      ok($test_array[0] eq 'test_14',   "alarm 14 remove: name is correct");
+      ok($test_array[1] == 1,           "alarm 14 remove: time is correct");
+      is_deeply($test_array[2], [ 14 ], "alarm 14 remove: data is correct");
 
       # Have time stand still so we can test against it.
       # Heisenberg strikes again!
@@ -356,7 +362,7 @@ POE::Session->create(
           $test_scalar->[1] >= $now
         ),  "alarm 15 remove: time is correct"
       );
-      ok($test_scalar->[2] == 15, "alarm 15 remove: data is correct");
+      is_deeply($test_scalar->[2], [ 15 ], "alarm 15 remove: data is correct");
     },
 
     # This one is dispatched.
