@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: ses_session.pm 2426 2009-02-10 09:05:42Z rcaputo $
+# vim: ts=2 sw=2 expandtab
 
 # Tests basic compilation and events.
 
@@ -7,15 +7,21 @@ use strict;
 
 use lib qw(./mylib ../mylib);
 
+sub POE::Kernel::ASSERT_DEFAULT () { 1 }
+
 BEGIN {
-  sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-  sub POE::Kernel::TRACE_DEFAULT  () { 1 }
-  sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
+  package POE::Kernel;
+BEGIN {
+  $POE::Kernel::VERSION = '1.311';
+}
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
 }
 
-use Test::More tests => 44;
+use Test::More tests => 41;
 use POE;
 
+diag("This test generates some STDERR during trace testing.");
+
 ### Test parameters and results.
 
 my $machine_count  = 10;
@@ -130,6 +136,7 @@ POE::Session->create(
       $_[KERNEL]->sig( ALRM => undef );
       $_[KERNEL]->sig( PIPE => undef );
     },
+    _stop => sub { }, # Pacify assertions.
   }
 );
 
@@ -165,6 +172,7 @@ POE::Session->create(
     query => sub {
       $_[ARG0]->( ++$_[HEAP]->{response} );
     },
+    _stop => sub { }, # Pacify assertions.
   },
 );
 
@@ -206,12 +214,12 @@ POE::Session->create(
       }
     },
     _stop => sub {
-      ok(
-        $_[KERNEL]->get_active_session() == $_[SESSION],
+      is(
+        $_[KERNEL]->get_active_session(), $_[SESSION],
         "get_active_session within session"
       );
-      ok(
-        $_[KERNEL]->get_active_session()->get_heap() == $_[HEAP],
+      is(
+        $_[KERNEL]->get_active_session()->get_heap(), $_[HEAP],
         "get_heap during stop"
       );
     },
@@ -222,6 +230,9 @@ POE::Session->create(
 # Unmapped package session.
 
 package UnmappedPackage;
+BEGIN {
+  $UnmappedPackage::VERSION = '1.311';
+}
 use POE::Session; # for constants
 
 sub _start {
@@ -243,6 +254,9 @@ sub _stop {
 # Unmapped object session.
 
 package UnmappedObject;
+BEGIN {
+  $UnmappedObject::VERSION = '1.311';
+}
 use POE::Session; # for constants
 
 # Trivial constructor.
@@ -267,6 +281,9 @@ sub _stop {
 # Unmapped package session.
 
 package MappedPackage;
+BEGIN {
+  $MappedPackage::VERSION = '1.311';
+}
 use POE::Session; # for constants
 
 sub my_start {
@@ -288,6 +305,9 @@ sub my_stop {
 # Unmapped object session.
 
 package MappedObject;
+BEGIN {
+  $MappedObject::VERSION = '1.311';
+}
 use POE::Session; # for constants
 
 # Trivial constructor.
@@ -312,6 +332,9 @@ sub my_stop {
 # Test the Package and Object sessions.
 
 package main;
+BEGIN {
+  $main::VERSION = '1.311';
+}
 
 # New style (create) object session without event to method name map.
 POE::Session->create(
@@ -370,6 +393,7 @@ POE::Session->create(
       $_[KERNEL]->yield("idle");
     },
     idle => sub { },
+    _stop => sub { }, # Pacify assertions.
   },
   options => { default => 1 },
 );
@@ -385,15 +409,15 @@ ok($@ ne '', "create() doesn't accept an odd number of args");
 #------------------------------------------------------------------------------
 # Main loop.
 
-ok(
-  $poe_kernel->get_active_session() == $poe_kernel,
+is(
+  $poe_kernel->get_active_session(), $poe_kernel,
   "get_active_session before POE::Kernel->run()"
 );
 
 POE::Kernel->run();
 
-ok(
-  $poe_kernel->get_active_session() == $poe_kernel,
+is(
+  $poe_kernel->get_active_session(), $poe_kernel,
   "get_active_session after POE::Kernel->run()"
 );
 
@@ -402,25 +426,25 @@ ok(
 
 # Now make sure they've run.
 for (my $i=0; $i<$machine_count; $i++) {
-  ok(
-    $completions[$i] == $event_count,
+  is(
+    $completions[$i], $event_count,
     "test $i ran"
   );
 }
 
 # Were all the signals caught?
 SKIP: {
-  if ($^O eq "MSWin32" or $^O eq "MacOS") {
+  if (($^O eq "MSWin32" or $^O eq "MacOS") and not $ENV{POE_DANTIC}) {
     skip "$^O does not support signals", 2;
   }
 
-  ok(
-    $sigalrm_caught == $event_count,
+  is(
+    $sigalrm_caught, $event_count,
     "caught enough SIGALRMs"
   );
 
-  ok(
-    $sigpipe_caught == $event_count,
+  is(
+    $sigpipe_caught, $event_count,
     "caught enough SIGPIPEs"
   );
 }
@@ -437,28 +461,26 @@ ok(
   "ARG constants are good"
 );
 
-ok(
-  $sender_count == $machine_count * $event_count,
+is(
+  $sender_count, $machine_count * $event_count,
   "sender_count"
 );
 
-ok(
-  $default_count == $machine_count * $event_count,
+is(
+  $default_count, $machine_count * $event_count,
   "default_count"
 );
 
-ok(
-  $got_heap_count == $machine_count,
+is(
+  $got_heap_count, $machine_count,
   "got_heap_count"
 );
 
 # Object/package sessions.
-for (0..3) {
-  ok(
-    $objpack[$_] == $event_count,
-    "object/package session $_ event count"
-  );
-}
+is_deeply(
+  \@objpack, [ ($event_count) x 4 ],
+  "object/package session event count"
+);
 
 my $sessions_destroyed = 0;
 my $objects_destroyed = 0;
@@ -467,6 +489,9 @@ my $parent_called = 0;
 my $child_called = 0;
 
 package POE::MySession;
+BEGIN {
+  $POE::MySession::VERSION = '1.311';
+}
 
 use vars qw(@ISA);
 
@@ -479,6 +504,9 @@ sub DESTROY {
 }
 
 package MyObject;
+BEGIN {
+  $MyObject::VERSION = '1.311';
+}
 
 sub new { bless {} }
 sub DESTROY { $objects_destroyed++ }
@@ -568,8 +596,8 @@ POE::MySession->create(
         $expected = 3;
       }
 
-      ok(
-        $sessions_destroyed == $expected,
+      is(
+        $sessions_destroyed, $expected,
         "$sessions_destroyed sessions destroyed (expected $expected)"
       );
 
@@ -582,11 +610,12 @@ POE::MySession->create(
         $expected = 3;
       } else {
         $expected = 2;
-        diag( "Your version of Perl is rather buggy.  Consider upgrading." );
+        diag("Detected a memory leak in Perl version $].");
+        diag("Please consider upgrading if you use Perl in production.");
       }
 
-      ok(
-        $objects_destroyed == $expected,
+      is(
+        $objects_destroyed, $expected,
         "$objects_destroyed objects destroyed (expected $expected)"
       );
     }
@@ -595,18 +624,18 @@ POE::MySession->create(
 
 POE::Kernel->run();
 
-ok(
-  $stop_called == 0,
+is(
+  $stop_called, 0,
   "_stop wasn't called"
 );
 
-ok(
-  $child_called == 0,
+is(
+  $child_called, 0,
   "_child wasn't called"
 );
 
-ok(
-  $parent_called == 0,
+is(
+  $parent_called, 0,
   "_parent wasn't called"
 );
 
@@ -620,8 +649,8 @@ else {
   $expected = 4;
 }
 
-ok(
-  $sessions_destroyed == $expected,
+is(
+  $sessions_destroyed, $expected,
   "destroyed $sessions_destroyed sessions (expected $expected)"
 );
 
@@ -640,8 +669,8 @@ else {
   $expected = 4;
 }
 
-ok(
-  $objects_destroyed == $expected,
+is(
+  $objects_destroyed, $expected,
   "destroyed $objects_destroyed objects (expected $expected)"
 );
 
