@@ -111,10 +111,10 @@ my @tests = (
       "\eb\eb",
       "\et",            # transpose-words
       "\cA\cT",         # transpose-chars (fail bol)
-      "\cE\cT",         # transpose-chars (fail eol)
+      "\cE12\cT",       # transpose-chars (at eol
       "\cJ",
     ],
-    done => "two one 21",
+    done => "two one 2121",
   },
 );
 
@@ -123,6 +123,9 @@ sub POE::Kernel::ASSERT_DEFAULT () { 1 }
 
 BEGIN {
   package POE::Kernel;
+BEGIN {
+  $POE::Kernel::VERSION = '1.311';
+}
   use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
 }
 
@@ -164,8 +167,11 @@ BEGIN {
     $termios->getattr();
     my $ospeed = $termios->getospeed() || eval { POSIX::B38400() } || 0;
 
-    my $term = $ENV{TERM} || 'vt100';
-    my $termcap = eval { Term::Cap->Tgetent( { TERM => $term, OSPEED => $ospeed } ) };
+    $ENV{TERM} = "vt100" if $^O eq "solaris" or not $ENV{TERM};
+
+    my $termcap = eval {
+      Term::Cap->Tgetent( { TERM => $ENV{TERM}, OSPEED => $ospeed } )
+    };
     unless ($termcap) {
       $error = "Term::Cap failure: $@";
       $error =~ s/ at \S+ line \d+.*//;
@@ -250,9 +256,9 @@ END {
 use POE qw(Filter::Stream Wheel::ReadWrite);
 
 eval "use POE::Wheel::ReadLine";
-if ($@ and $@ =~ /(requires a termcap|failed termcap lookup)/) {
+if ($@ and $@ =~ /(requires a termcap|failed termcap lookup|cannot run)/) {
   my $error = $@;
-  $error =~ s/ at \S+ line \d+.*//;
+  $error =~ s/ at \S+ line \d+.*//s;
   $error =~ s/\s+/ /g;
   plan skip_all => $error;
 }
@@ -281,6 +287,28 @@ POE::Kernel->run();
 sub test_start {
   my ($kernel, $heap) = @_[KERNEL, HEAP];
 
+  # The ReadLine wheel to drive and test.
+
+  eval {
+    $heap->{readline} = POE::Wheel::ReadLine->new(
+      InputEvent => "got_readline_input",
+      appname => "my_cli",
+    );
+  };
+
+  if ($@) {
+    my $error = $@;
+    $error =~ s/ at \S+ line \d+.*//s;
+    $error =~ s/\s+/ /g;
+    plan skip_all => $error;
+    return;
+  }
+
+  unless ($heap->{readline}) {
+    plan skip_all => "POE::Wheel::Readline->new failed (term=$ENV{TERM})";
+    return;
+  }
+
   # Create a Wheel::ReadWrite to work on the driving side of the
   # pipes.
 
@@ -290,14 +318,6 @@ sub test_start {
     InputEvent => "got_readwrite_output",
   );
 
-  # The ReadLine wheel to drive and test.
-
-  eval {
-    $heap->{readline} = POE::Wheel::ReadLine->new(
-      InputEvent => "got_readline_input",
-      appname => "my_cli",
-    );
-  };
 
   # And start testing.
 
