@@ -1,26 +1,34 @@
 #!/usr/bin/perl
+# vim: ts=2 sw=2 expandtab
 
 use strict;
 use warnings;
 
 sub DEBUG () { 0 }
 my $REFCNT;
+
 sub POE::Kernel::USE_SIGCHLD () { 1 }
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-sub POE::Kernel::TRACE_SIGNALS () { 0 }
-sub POE::Kernel::TRACE_REFCNT () { DEBUG and $REFCNT }
+
+BEGIN {
+  package POE::Kernel;
+BEGIN {
+  $POE::Kernel::VERSION = '1.311';
+}
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
+}
 
 use Test::More;
 use POSIX qw( SIGINT SIGUSR1 );
 use POE;
 use POE::Wheel::Run;
 
-if ($^O eq "MSWin32") {
+if ($^O eq "MSWin32" and not $ENV{POE_DANTIC}) {
   plan skip_all => "SIGUSR1 not supported on $^O";
   exit 0;
 }
 
-if ($INC{'Tk.pm'}) {
+if ($INC{'Tk.pm'} and not $ENV{POE_DANTIC}) {
   plan skip_all => "Test causes XIO and other errors under Tk.";
   exit 0;
 }
